[![CI](https://github.com/post-luxembourg/pydevice42/workflows/CI/badge.svg)](https://github.com/post-luxembourg/pydevice42/actions?query=workflow%3ACI)
[![PyPI](https://img.shields.io/pypi/v/pydevice42)](https://pypi.org/project/pydevice42/)

# pydevice42

## Installation

```shell
pip install pydevice42
```

## Usage

```python
from pydevice42 import D42Client

client = D42Client(hostname="device42.com", username="admin", password="admin")
```
